/*
** Copyright (C) 2001-2024 by Carnegie Mellon University.
**
** @OPENSOURCE_LICENSE_START@
**
** SiLK 3.23
**
** Copyright 2024 Carnegie Mellon University.
**
** NO WARRANTY. THIS CARNEGIE MELLON UNIVERSITY AND SOFTWARE ENGINEERING
** INSTITUTE MATERIAL IS FURNISHED ON AN "AS-IS" BASIS. CARNEGIE MELLON
** UNIVERSITY MAKES NO WARRANTIES OF ANY KIND, EITHER EXPRESSED OR
** IMPLIED, AS TO ANY MATTER INCLUDING, BUT NOT LIMITED TO, WARRANTY OF
** FITNESS FOR PURPOSE OR MERCHANTABILITY, EXCLUSIVITY, OR RESULTS
** OBTAINED FROM USE OF THE MATERIAL. CARNEGIE MELLON UNIVERSITY DOES NOT
** MAKE ANY WARRANTY OF ANY KIND WITH RESPECT TO FREEDOM FROM PATENT,
** TRADEMARK, OR COPYRIGHT INFRINGEMENT.
**
** Licensed under a GNU GPL 2.0-style license, please see LICENSE.txt or
** contact permission@sei.cmu.edu for full terms.
**
** [DISTRIBUTION STATEMENT A] This material has been approved for public
** release and unlimited distribution.  Please see Copyright notice for
** non-US Government use and distribution.
**
** This Software includes and/or makes use of Third-Party Software each
** subject to its own license.
**
** DM24-1064
**
** @OPENSOURCE_LICENSE_END@
*/
#ifndef _INTERVAL_H
#define _INTERVAL_H
#ifdef __cplusplus
extern "C" {
#endif

#include <silk/silk.h>

RCSIDENTVAR(rcsID_INTERVAL_H, "$SiLK: interval.h 6c9dfbe0b623 2024-01-17 18:02:34Z mthomas $");


int
intervalInit(
    void);
void
intervalShutdown(
    void);
double *
intervalQuartiles(
    const uint32_t     *data,
    const uint32_t     *intervals,
    uint32_t            numIntervals);
double *
intervalMoments(
    const uint32_t     *data,
    const uint32_t     *intervals,
    uint32_t            numIntervals);


#define NUM_INTERVALS   10

/*
** intervals are defined for each protocol separately. Till we decide
** we want to change it, treat icmp like udp
*/
extern uint32_t tcpByteIntervals[NUM_INTERVALS];
extern uint32_t udpByteIntervals[NUM_INTERVALS];
extern uint32_t tcpPktIntervals[NUM_INTERVALS];
extern uint32_t udpPktIntervals[NUM_INTERVALS];
extern uint32_t tcpBppIntervals[NUM_INTERVALS];
extern uint32_t udpBppIntervals[NUM_INTERVALS];

#ifdef __cplusplus
}
#endif
#endif /* _INTERVAL_H */

/*
** Local Variables:
** mode:c
** indent-tabs-mode:nil
** c-basic-offset:4
** End:
*/
